const geolib = require('geolib');

function withinLondon(lat, lon) {
  const LAT = 51.500152;
  const LON = -0.126236;
  const RADIUS = 50 * 1000; // 50 kms
  return geolib.isPointInCircle(
    {
      latitude: lat,
      longitude: lon
    },
    {
      latitude: LAT,
      longitude: LON
    },
    RADIUS
  );
}

module.exports = function(total) {
  // Just photos with geo location
  total = total.filter((photo) => {
    return photo.latitude != 0;
  });
  //console.log('Total photos with lat and lon ', total.length);

  // Unique lat and lon
  locations = {};
  total = total.filter((photo) => {
    var lon = locations[photo.latitude];
    if (lon && lon == photo.longitude) {
      // Same location
      return false;
    }

    if (!withinLondon(photo.latitude, photo.longitude)) {
      return false;
    }

    locations[photo.latitude] = photo.longitude;
    return photo;
  });

  // Add flicker photo and geojson fields
  total = total.map((photo) => {
    photo.url = `https://www.flickr.com/photos/${photo.owner}/${photo.id}`;
    photo.thumbnail = `https://farm${photo.farm}.staticflickr.com/${photo.server}/${photo.id}_${photo.secret}_t.jpg`;

    // To geojson
    photo.type = 'Feature';
    photo.properties = {
      image: photo.thumbnail
    };
    photo.geometry = {};
    photo.geometry.type = 'Point',
    photo.geometry.coordinates = [parseFloat(photo.longitude), parseFloat(photo.latitude)];


    return photo;
  });

  //console.log('Total photos with unique lat and lon ', total.length);
  // Transfor to geojson object
  const geojson = {
    type: 'FeatureCollection',
    features: total
  };

  return geojson;
}
